@@ -27,14 +27,14 @@ fn main() {
         )
         .get_matches();
 
-    let vertex = matches
+    let dag = matches
         .value_of("in")
         .expect("A valid DAG needs to be provided");
     let strip = matches
         .value_of("strip")
         .expect("A valid character to strip needs to be provided");
 
-    let stripped_dag = strip_dag(vertex, strip);
+    let stripped_dag = strip_dag(dag, strip);
 
     println!("The new DAG is : {}", stripped_dag)
 }
